@@ -4,6 +4,7 @@
 '''Defines various tools for pickling and unpickling.'''
 
 
+import zlib
 import re
 import cPickle as pickle_module
 import pickle # Importing just to get dispatch table, not pickling with it.
@@ -186,4 +187,10 @@ class CuteUnpickler(object):
             raise pickle_module.UnpicklingError('Invalid persistent id')
  
  
-    
\ No newline at end of file
+def compickle(thing):
+    '''Pickle `thing` and compress it using `zlib`.'''
+    return zlib.compress(pickle_module.dumps(thing, protocol=2))
+
+def decompickle(thing):
+    '''Unpickle `thing` after decompressing it using `zlib`.'''
+    return pickle_module.loads(zlib.decompress(thing))
\ No newline at end of file
